package com.yijia.label.service;

import java.util.List;

import com.yijia.label.domain.LabelRule;
import com.yijia.label.domain.LabelRuleDetail;

/**
 * 标签规则明细Service接口
 * 
 * @author yijia
 * @date 2021-06-15
 */
public interface ILabelRuleDetailService 
{
    /**
     * 查询标签规则明细
     * 
     * @param id 标签规则明细ID
     * @return 标签规则明细
     */
    public LabelRuleDetail selectLabelRuleDetailById(Integer id);

    /**
     * 查询标签规则明细列表
     * 
     * @param labelRuleDetail 标签规则明细
     * @return 标签规则明细集合
     */
    public List<LabelRuleDetail> selectLabelRuleDetailList(LabelRuleDetail labelRuleDetail);

    /**
     * 新增标签规则明细
     * 
     * @param labelRuleDetail 标签规则明细
     * @return 结果
     */
    public int insertLabelRuleDetail(LabelRuleDetail labelRuleDetail);

    /**
     * 修改标签规则明细
     * 
     * @param labelRuleDetail 标签规则明细
     * @return 结果
     */
    public int updateLabelRuleDetail(LabelRuleDetail labelRuleDetail);

    /**
     * 批量删除标签规则明细
     * 
     * @param ids 需要删除的标签规则明细ID
     * @return 结果
     */
    public int deleteLabelRuleDetailByIds(Integer[] ids);

    /**
     * 删除标签规则明细信息
     * 
     * @param id 标签规则明细ID
     * @return 结果
     */
    public int deleteLabelRuleDetailById(Integer id);

    /**
     * 查询规则明细
     * @param labelRule
     * @return
     */
    public List<LabelRuleDetail> labelRuleDetailList(LabelRule labelRule);
}
